#!/usr/bin/perl -w

# read in .lst file from cutSequences.pl and change chromosome identifieres from NcDNAlign adopted ones to original chromosome identifier.

# lst file: first entry is adopted, second is original

use Getopt::Long;
use strict;

my $usage= << "JUS";
  usage: perl $0 -lst FILE -f FORMAT -i FILE
  
  options: -lst:    	Mapping file produced by cutSequences.pl	[REQUIRED]
           -f|format    Specify the input format, 			[REQUIRED]
			do we have [BED|FASTA] input?
	   -i|input 	The input file which should be changed	   	[REQUIRED]
  
  purpose: read in .lst file from cutSequences.pl and change chromosome identifieres from NcDNAlign adopted ones to original chromosome identifier.
  
  results: Prints adopted data to STDOUT
JUS

my ($opt_i, $opt_f, $opt_lst) = ('', '', '');

GetOptions(
	"lst=s"		=> \$opt_lst,
	"f|format=s"	=> \$opt_f,
	"i|input=s"	=> \$opt_i
) or pod2usage(2);

if(!$opt_lst|| $opt_f!~/[BED|FASTA]/ || !$opt_i ) {
	print STDERR $usage;
	exit;
}

my %lst;

open(IN, "< $opt_lst") or die "ERROR: Can not open file='$opt_lst'!\n";

# set up hash and read in input
while (<IN>) {
	my $line = $_;
	if($line =~ /^(\S+)\t(\S+)$/) {
		$lst{$1}=$2;
	}
	else {
		die "ERROR: wrong .lst format! line='$line'!\n";
	}

}
close IN;

open(IN, "< $opt_i") or die "ERROR: Can not open file='$opt_i'!\n";

if($opt_f=~ /BED/) {
	while (<IN>) {
		my $line = $_;
		if($line =~ /^(\S+)\t(.+)$/) {
			#print "1=$1\n";
			print "$lst{$1}\t$2\n";
		}
		else {
			die "ERROR: wrong format! line='$line'!\n";
		}
	}
}
elsif($opt_f=~/FASTA/) {
	while (<IN>) {
		my $line = $_;
		if($line =~ /^>(\S\S\S\_\d+)(.+)$/) {
			print ">$lst{$1}$2\n";
		}
		else {
			print $line;
		}
	}
}
close IN;



